##########################################################
## Fraga Hersh (2011) Replication Code, April 15, 2011 ##
## Compiled using R ver. 2.10.1 ########################
## Packages as of April 15, 2011 ######################
######################################################

install.packages("Zelig")
install.packages("lme4")

library(Zelig)
library(cem)
library(foreign)
weatherdata <- read.dta("FragaHersh_Data.dta")
# Note: Datafile must be in same working directory as .R file
# Data should have 43340 observations

LikRatio <- function(null.LLik, model.LLik){
	-2*(null.LLik - model.LLik)
	}

###############################################################
## Figure 1: Bivariate Relationship Between Rain and Turnout ##
par(xaxt="n")
par(yaxt="n")
par(mar=c(3.5,4.5,1.5,1.5))
plot(weatherdata$Rain, weatherdata$Turnout, cex=.66, ylab="", col="gray25", xlim=c(0,4.6))
segments(x0=0, x1=4.53, y0=58.928, y1=(58.928+(-3.278*4.53)), lwd=2)
mtext(side=1, text="Rainfall on Election Day", line=1.5)
mtext(side=2, text="County Turnout", line=2.5)
axis(1, at=seq(0,4.5,0.5), labels=FALSE)
axis(2, at=seq(0,100,20), labels=FALSE)
text(x = seq(0,4.5,0.5), par("usr")[3], labels=c("0''","0.5''","1''", "1.5''","2''","2.5''","3''","3.5''","4''","4.5''"), pos=1, xpd=TRUE, cex=.75)
text(y = seq(0,100,20), par("usr")[1], labels=c("0%","20%","40%","60%","80%","100%"), srt=0, pos=2, xpd=TRUE, cex=.75)
at.y <- seq(0,100,20)
segments(par("usr")[1], at.y, par("usr")[1]-((par("usr")[2]-par("usr")[1])*0.0075), at.y, xpd=TRUE)

############################################################
## Figure 2: Bivariate Relationship, Uncompetitive States ##
nosouth <- weatherdata[weatherdata$State != "VIRGINIA" & weatherdata$State != "NORTH CAROLINA" & weatherdata$State != "SOUTH CAROLINA" & weatherdata$State != "GEORGIA" & weatherdata$State != "FLORIDA" & weatherdata$State != "ALABAMA" & weatherdata$State != "TENNESSEE"  & weatherdata$State != "MISSISSIPPI" & weatherdata$State != "ARKANSAS" & weatherdata$State != "LOUISIANA" & weatherdata$State != "TEXAS",]

uncompetdataNS <- nosouth[nosouth$post_competitive<=0.7,]
reg1 <- coef(summary(lm(Turnout~Rain,data=uncompetdataNS)))
uncompetdata <- weatherdata[weatherdata$post_competitive<=0.7,]
reg2 <- coef(summary(lm(Turnout~Rain,data=uncompetdata)))

par(xaxt="n")
par(yaxt="n")
par(mar=c(3.5,4.5,1.5,1.5))
plot(uncompetdata$Rain, uncompetdata$Turnout, cex=.66, ylab="", col="gray50", xlim=c(0,4.53))
points(uncompetdataNS$Rain, uncompetdataNS$Turnout, cex=.66, ylab="", col="gray25")
segments(x0=0, x1=1.3, y0=reg1[1], y1=(reg1[1]+(reg1[2]*1.3)), lwd=2, col="black")
segments(x0=0, x1=4.53, y0=reg2[1], y1=(reg2[1]+(reg2[2]*4.53)), lwd=2, col="gray50", lty=2)
mtext(side=1, text="Rainfall on Election Day", line=1.5)
mtext(side=2, text="County Turnout", line=2.5)
axis(1, at=seq(0,4.5,0.5), labels=FALSE)
axis(2, at=seq(0,100,20), labels=FALSE)
text(x = seq(0,4.5,0.5), par("usr")[3], labels=c("0''","0.5''","1''", "1.5''","2''","2.5''","3''","3.5''","4''","4.5''"), pos=1, xpd=TRUE, cex=.75)
text(y = seq(0,100,20), par("usr")[1], labels=c("0%","20%","40%","60%","80%","100%"), srt=0, pos=2, xpd=TRUE, cex=.75)
at.y <- seq(0,100,20)
segments(par("usr")[1], at.y, par("usr")[1]-((par("usr")[2]-par("usr")[1])*0.0075), at.y, xpd=TRUE)

##########################################################
## Figure 3: Bivariate Relationship, Competitive States ##
competdataNS <- nosouth[nosouth$post_competitive>=.96,]
reg3 <- coef(summary(lm(Turnout~Rain,data=competdataNS)))
competdata <- weatherdata[weatherdata$post_competitive>=.96,]
reg4 <- coef(summary(lm(Turnout~Rain,data=competdata)))

par(xaxt="n")
par(yaxt="n")
par(mar=c(3.5,4.5,1.5,1.5))
plot(competdata$Rain, competdata$Turnout, cex=.66, ylab="", col="gray50", xlim=c(0,2.12), ylim=c(0,100))
points(competdataNS$Rain, competdataNS$Turnout, cex=.66, ylab="", col="gray25")
segments(x0=0, x1=2.1, y0=reg3[1], y1=(reg3[1]+(reg3[2]*2.1)), lwd=2, col="black")
segments(x0=0, x1=2.1, y0=reg4[1], y1=(reg4[1]+(reg4[2]*2.1)), lwd=2, col="gray50", lty=2)
mtext(side=1, text="Rainfall on Election Day", line=1.5)
mtext(side=2, text="County Turnout", line=2.5)
axis(1, at=seq(0,2.12,0.5), labels=FALSE)
axis(2, at=seq(0,100,20), labels=FALSE)
text(x = seq(0,2.12,0.5), par("usr")[3], labels=c("0''","0.5''","1''", "1.5''","2''"), pos=1, xpd=TRUE, cex=.75)
text(y = seq(0,100,20), par("usr")[1], labels=c("0%","20%","40%","60%","80%","100%"), srt=0, pos=2, xpd=TRUE, cex=.75)
at.y <- seq(0,100,20)
segments(par("usr")[1], at.y, par("usr")[1]-((par("usr")[2]-par("usr")[1])*0.0075), at.y, xpd=TRUE)

########################
## Matching Procedure ##
weatherdata$count <- 1
weatherdata$Treatment <- ifelse(weatherdata$Rain > 0, 1, 0)

drop <- c(names(weatherdata[-c(45,85)]))
# Drop all columns except for avg_rain and the count variable

mat <- cem(treatment="Treatment", data=weatherdata, drop=drop)
write.csv(mat[17], "matches.csv")
# Can examine this file to find observations that are unmatched, should be 6
unmatched <- c(40866, 40874, 40893, 41136, 41155, 41160)
weatherdata <- weatherdata[-unmatched,]
# Data should now have 43334 observations

###############################################################
## Remove Observations where national Democrat not on Ballot ##
weatherdata <- weatherdata[weatherdata$no_dem == 0,]
# Data should now have 43118 observations

######################
## Table 1, Model 1 ##
z.null <- zelig(Turnout ~ 1, data=weatherdata, model="ls")
logLik(z.null)

z.table1.1 <- zelig(Turnout ~ Rain + Snow + Turnout_Lag + avg_rain + avg_snow + Yr52 + Yr56 + Yr60 + Yr64 + Yr68 + Yr72 + Yr76 + Yr80 + Yr84 + Yr88 + Yr92 + Yr96 + Yr2000 + tag(1|FIPS_County), data=weatherdata, model="ls.mixed")
print(z.table1.1, correlation=FALSE)
LikRatio(-175861.8, logLik(z.table1.1)[1])

######################
## Table 1, Model 2 ##
z.table1.2 <- zelig(Turnout ~ Rain + Snow + post_competitive + Rain*post_competitive + Snow*post_competitive + Turnout_Lag + avg_rain + avg_snow + Yr52 + Yr56 + Yr60 + Yr64 + Yr68 + Yr72 + Yr76 + Yr80 + Yr84 + Yr88 + Yr92 + Yr96 + Yr2000 + tag(1|FIPS_County), data=weatherdata, model="ls.mixed")
print(z.table1.2, correlation=FALSE)
LikRatio(-175861.8, logLik(z.table1.2)[1])

######################
## Table 1, Model 3 ##
z.table1.3 <- zelig(Turnout ~ Rain + Snow + post_competitive + Rain*post_competitive + Snow*post_competitive + ZPcntHSGrad + AdjIncome + PcntBlack + FarmsPerCap + Closing + Motor + Property + Literacy + PollTax + GubElection + SenElection + Turnout_Lag + avg_rain + avg_snow + Yr52 + Yr56 + Yr60 + Yr64 + Yr68 + Yr72 + Yr76 + Yr80 + Yr84 + Yr88 + Yr92 + Yr96 + Yr2000 + tag(1|FIPS_County), data=weatherdata, model="ls.mixed")
print(z.table1.3, correlation=FALSE)
LikRatio(-175861.8, logLik(z.table1.3)[1])

######################
## Table 1, Model 4 ##
z.table1.4 <- zelig(Turnout ~ Rain + Snow + ante_competitive + Rain*ante_competitive + Snow*ante_competitive + Turnout_Lag + avg_rain + avg_snow + Yr52 + Yr56 + Yr60 + Yr64 + Yr68 + Yr72 + Yr76 + Yr80 + Yr84 + Yr88 + Yr92 + Yr96 + Yr2000 + tag(1|FIPS_County), data=weatherdata, model="ls.mixed")
print(z.table1.4, correlation=FALSE)
LikRatio(-175861.8, logLik(z.table1.4)[1])

######################
## Table 1, Model 5 ##
z.table1.5 <- zelig(Turnout ~ Rain + Snow + ante_competitive + Rain*ante_competitive + Snow*ante_competitive + ZPcntHSGrad + AdjIncome + PcntBlack + FarmsPerCap + Closing + Motor + Property + Literacy + PollTax + GubElection + SenElection + Turnout_Lag + avg_rain + avg_snow + Yr52 + Yr56 + Yr60 + Yr64 + Yr68 + Yr72 + Yr76 + Yr80 + Yr84 + Yr88 + Yr92 + Yr96 + Yr2000 + tag(1|FIPS_County), data=weatherdata, model="ls.mixed")
print(z.table1.5, correlation=FALSE)
LikRatio(-175861.8, logLik(z.table1.5)[1])

####################################################################
## Figure 4: Simulated Outcomes, Compet and Uncompet Environments ##
x.low <- setx(z.table1.3, Rain=seq(0,2,.025), post_competitive=.70)
x.high <- setx(z.table1.3, Rain=seq(0,2,.025), post_competitive=.96)
s.out   <- sim(z.table1.3, x=x.low, x1=x.high)

par(xaxt="n")
par(yaxt="n")
par(mar=c(3.5,4.5,1.5,1.5))
plot.ci(s.out, lwd=3, col=c("gray50", "black"), ann=TRUE, ylab="",ylim=c(55,61))
text(x=0.35, y=60.5,"Competitive State", font=4, cex=0.8)
text(x=0.35, y=60.2,"(4% Margin of Victory)", font=1, cex=0.6)
text(x=1.65, y=57.9,"Uncompetitive State", font=4, cex=0.8, col="gray50")
text(x=1.65, y=57.6,"(30% Margin of Victory)", font=1, cex=0.6, col="gray50")
mtext(side=1, text="Rainfall on Election Day", line=1.5)
mtext(side=2, text="County Turnout", line=2.5)
axis(1, at=seq(0,2,0.5), labels=FALSE)
axis(2, at=seq(55,61,1), labels=FALSE)
text(x = seq(0,2,0.5), par("usr")[3], labels=c("0''","0.5''","1''", "1.5''","2''"), pos=1, xpd=TRUE, cex=.75)
text(y = seq(55,61,1), par("usr")[1], labels=c("55%","56%","57%","58%","59%","60%","61%"), srt=0, pos=2, xpd=TRUE, cex=.75)
at.y <- seq(55,61,1)
segments(par("usr")[1], at.y, par("usr")[1]-((par("usr")[2]-par("usr")[1])*0.0075), at.y, xpd=TRUE)

######################################
## Appendix 1: Fixed Effects Models ############
## NOTE: These were run in Stata SE ver. 11.1 ##

write.dta(weatherdata, "FragaHersh_Data_Matched.dta", version=10, convert.factors="string")

## The following commands should be run in Stata, remove initial # to run. Use the above dataset generated by R to ensure number of observations stays the same. ##

#gen rain_compet = Rain*post_competitive
#gen snow_compet = Snow*post_competitive
#gen rain_compet2 = Rain*ante_competitive
#gen snow_compet2 = Snow*ante_competitive
#xtset FIPS_County

#xtreg Turnout Turnout_Lag Rain Snow Yr52 Yr56 Yr60 Yr64 Yr68 Yr72 Yr76 Yr80 Yr84 Yr88 Yr92 Yr96 Yr2000 avg_rain avg_snow, fe

#xtreg Turnout Turnout_Lag post_competitive rain_compet snow_compet Rain Snow Yr52 Yr56 Yr60 Yr64 Yr68 Yr72 Yr76 Yr80 Yr84 Yr88 Yr92 Yr96 Yr2000 avg_rain avg_snow, fe

#xtreg Turnout Turnout_Lag post_competitive rain_compet snow_compet Rain Snow PcntBlack ZPcntHSGrad FarmsPerCap AdjIncome Closing Property Literacy PollTax Motor GubElection SenElection Yr52 Yr56 Yr60 Yr64 Yr68 Yr72 Yr76 Yr80 Yr84 Yr88 Yr92 Yr96 Yr2000 avg_rain avg_snow, fe

#xtreg Turnout Turnout_Lag ante_competitive rain_compet2 snow_compet2 Rain Snow Yr52 Yr56 Yr60 Yr64 Yr68 Yr72 Yr76 Yr80 Yr84 Yr88 Yr92 Yr96 Yr2000 avg_rain avg_snow, fe

#xtreg Turnout Turnout_Lag ante_competitive rain_compet2 snow_compet2 Rain Snow PcntBlack ZPcntHSGrad FarmsPerCap AdjIncome Closing Property Literacy PollTax Motor GubElection SenElection Yr52 Yr56 Yr60 Yr64 Yr68 Yr72 Yr76 Yr80 Yr84 Yr88 Yr92 Yr96 Yr2000 avg_rain avg_snow, fe